import { ListSOP } from '../../libappsop/listsop';
import { FormSOP } from '../../libappsop/formsop';
import { DialogPostponeForecast } from '../dialogs/dialog.postponeforecast';
import { DialogCustomerOrder } from '../dialogs/dialog.customerorder';

export class FormCustomerOrders extends FormSOP {
  public listCustomerOrders = new ListCustomerOrders();
  public listCustomerOrdersPlanningLevel = new ListCustomerOrdersPlanningLevel();

  public constructor() {
    super('FormCustomerOrders');
  }
}

export class ListCustomerOrders extends ListSOP<DialogCustomerOrder, ListCustomerOrdersColumn> {
  public readonly title = 'Customer Orders';

  public constructor() {
    super('ListSalesDemands', new DialogCustomerOrder());

    // Set primary key column name(s), to display in error message when assert fails
    this.rowPrimaryColumnNames = {'Sales segment': '', 'Stocking point': '', Product: '', 'Order date': '', Quantity: ''};
    this.rowAllConstraintsColumnName = { 'All constraints': '' };
  }
}

export class ListCustomerOrdersPlanningLevel extends ListSOP<DialogPostponeForecast, ListCustomerOrdersPlanningLevelColumn> {
  public readonly title = 'Customer Orders at planning level';

  public constructor() {
    super('ListSDIP', new DialogPostponeForecast());
  }
}

// List Customer Orders columns
export interface ListCustomerOrdersColumn {
  'All constraints'?: string;
  Product?: string;
  'Sales segment'?: string;
  'Stocking point'?: string;
  'Order date'?: string;
  Quantity?: string;
  Price?: string;
  'Customer name'?: string;
  'Customer ID'?: string;
  'Order ID'?: string;
  'Order line ID'?: string;
}

export interface ListCustomerOrdersPlanningLevelColumn {
  Product?: string;
  'Sales segment'?: string;
  'Stocking point'?: string;
  Start?: string;
  End?: string;
  Quantity?: string;
}

// List CustomerOrders context menu items
const listCustomerOrdersContextMenuItem = {
  Create: { ContextMenu: 'listContextMenuSD', Name: 'MenuCreate', Label: 'Create' },
  Edit: { ContextMenu: 'listContextMenuSD', Name: 'MenuEdit', Label: 'Edit' },
  Delete: { ContextMenu: 'listContextMenuSD', Name: 'MenuDelete', Label: 'Delete' },
  AdjustQuantity: { ContextMenu: 'listContextMenuSD', Name: 'MenuAdjustQuantity', Label: 'Adjust Quantity...' },
};

const listCustomerOrdersPlanningLevelContextMenuItem = {
  Postpone: { ContextMenu: 'listContextMenuSDIP', Name: 'MenuPostpone', Label: 'Postpone' },
};

export { listCustomerOrdersContextMenuItem as ListCustomerOrdersContextMenuItem };
export { listCustomerOrdersPlanningLevelContextMenuItem as ListCustomerOrdersPlanningLevelContextMenuItem };
